'' =================================================================================================
''
''   File....... jm_sircs_rx_demo.spin
''   Purpose.... 
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (c) 2014 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started.... 
''   Updated.... 27 DEC 2014
''
'' =================================================================================================


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                           ' use 5MHz crystal
                                                                  
  CLK_FREQ = _xinfreq * (_clkmode >> 6)                          ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                    ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                                ' ticks in 1us
                                                                  
                                                                  
con  { io pins }                                                  
                                                                  
  RX1    = 31                                                    ' programming / terminal
  TX1    = 30                                                     
                                                                  
  SDA    = 29                                                    ' eeprom / i2c
  SCL    = 28                                                     
                                                                  
  ' connections/io on QuickStart HID Board                        
                                                                  
  K_CLK  = 27                                                    ' ps2 keyboard
  K_DTA  = 26                                                     
                                                                  
  M_CLK  = 25                                                    ' ps2 mouse
  M_DTA  = 24                                                     
                                                                  
  LED7   = 23                                                    ' leds
  LED6   = 22                                                     
  LED5   = 21                                                     
  LED4   = 20                                                     
  LED3   = 19                                                     
  LED2   = 18                                                     
  LED1   = 17                                                     
  LED0   = 16                                                     
                                                                  
  VGA    = 16                                                    ' vga base
                                                                  
  VIDEO  = 12                                                    ' composite video base
                                                                  
  A_LF   = 11                                                    ' audio pins
  A_RT   = 10                                                     
                                                                  
  IR_TX  =  9                                                    ' to ir led
  IR_RX  =  8                                                    ' from ir receiever
                                                                  
  SD_CS  =  3                                                    ' usd 
  SD_DI  =  2                                                     
  SD_CLK =  1                                                     
  SD_DO  =  0                                                     
                                                                  
                                                                  
obj                                                               
                                                                  
  io   : "jm_io"                                                 ' basic io
  time : "jm_time"                                               ' pause and timer
  term : "jm_fullduplexserial"                                   ' serial for terminal io
  sd   : "fsrw"                                                  ' for sd access

  irin : "jm_sircs_rx"                                           ' SIRCS input
  

var


dat

  Banner                byte    "==============================", 13
                        byte    " JonnyMac's HID SIRCS Sniffer ", 13
                        byte    "==============================", 13
                        byte    13
                        byte    0


pub main | key, bc

  setup

  ' open PST, select com port, enable, press a key

  term.rxflush
  term.rx


  ' SIRCS demo

  term.tx(term#CLS)
  term.str(@Banner)

  irin.enable                                                    ' allow ir input

  repeat
    key := irin.rx                                               ' wait for sircs
    bc   := irin.bit_count                                       ' get bit count
    irin.enable                                                  ' re-enable for next key

    case bc
      12:
        term.str(string("12 :: "))                               ' show bit count
        term.bin(key >> 7, 5)                                    ' show device key
        term.tx("_")                                             ' separater
        term.bin(key, 7)                                         ' show key key
        
      15:
        term.str(string("15 :: "))
        term.bin(key >> 7, 8)
        term.tx("_")
        term.bin(key, 7)
        
      20:
        term.str(string("20 :: "))
        term.bin(key >> 12, 8)
        term.tx("_")
        term.bin(key, 12)
        
      other:
        if (bc < 10)
          term.tx("0")
        term.dec(bc)
        term.str(string(" :: "))
        term.bin(key, bc)
        term.tx(" ")
        term.hex(key, 8)
        
    term.tx(term#CR)


pub setup

'' Setup IO and objects for application

  time.start

  term.start(RX1, TX1, %0000, 115_200)

  irin.start(IR_RX)

  time.pause(5)


dat  { license }

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}